@@ -5,6 +5,7 @@ import json
 import operator
 import config
 import math
+import wpad
 
 from time import time
 
@@ -29,10 +30,9 @@ def index(size):
     sorted_shoal.reverse()
     total = len(sorted_shoal)
 
-    non_digits = re.compile(r'[^\d]+')
     try:
-        size = int(non_digits.sub('', size))
-    except ValueError:
+        size = int(size)
+    except (ValueError, TypeError):
         size = 20
     page = int(page)
     try:
@@ -48,7 +48,12 @@ def index(size):
     lower, upper = get_slices(page,size)
     return render.index(time(), total, sorted_shoal[lower:upper], page, pages, size)
 
-def nearest(**k):
+def nearest(count):
+    try:
+        count = int(count)
+    except (ValueError, TypeError):
+        count = 5
+
     if web.ctx.query:
         try:
             ip = re.findall(r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}', web.ctx.query)[0]
@@ -57,17 +62,27 @@ def nearest(**k):
     else:
         ip = web.ctx['ip']
 
-    squids = geoip.get_nearest_squids(ip)
+    squids = geoip.get_nearest_squids(ip,count)
+
     web.header('Content-Type', 'application/json')
 
     if squids:
         squid_json = {}
         for i,squid in enumerate(squids):
-            squid_json[i] = {'public_ip':squid.public_ip, 'private_ip':squid.private_ip,}
-        return json.dumps(squid_json)
+            squid_json[i] = squid
+        squid_json = json.dumps(squid_json)
+        web.header('Content-Length', len(squid_json))
+        return squid_json
     else:
+        web.header('Content-Length', 4)
         return json.dumps(None)
 
 def external_ip(**k):
     ip = web.ctx['ip']
     return json.dumps({'external_ip':ip,})
+
+def wpad_generator(**k):
+    data = render.wpad(wpad.generate_wpad(web.ctx['ip']))
+    web.header('Content-Type', 'application/x-ns-proxy-autoconfig')
+    web.header('Content-Length', len(data['__body__']))
+    return data
